// Copyright (c) 2022-2023 VMware Carbon Black, all rights reserved

// Package devicetype -- enumeration copied from the monolith concerned with device types
package devicetype

import (
	"strings"
)

// DeviceType -- Enum of allowed device types
type DeviceType string

// IsKnown -- Returns true if a specified device type is a known definition
func (t DeviceType) IsKnown() bool {
	for _, element := range AllDeviceTypes {
		if t == element {
			return true
		}
	}
	return false
}

// NOTE: Changes here should also be reflected in `test/functional/suites/lib/models/enumerations.py`
//
// Note: Keep in sync with:
//   - https://gitlab.bit9.local/cb-defense/cbd/-/blob/main/backend/domainModel/src/main/java/com/scargo/domainmodel/entity/support/DeviceType.java
const (
	UNKNOWN DeviceType = "UNKNOWN"
	WINDOWS DeviceType = "WINDOWS"
	ANDROID DeviceType = "ANDROID"
	MAC     DeviceType = "MAC"
	IOS     DeviceType = "IOS"
	LINUX   DeviceType = "LINUX"
	OTHER   DeviceType = "OTHER"
)

// AllDeviceTypes -- List of all accepted DeviceType
var AllDeviceTypes = []DeviceType{ //nolint:gochecknoglobals // we don't care
	WINDOWS,
	ANDROID,
	MAC,
	IOS,
	LINUX,
	OTHER,
}

// FromString -- Convert incoming string to a DeviceType
//   - will be UNKNOWN if empty string or all spaces
func FromString(deviceType string) DeviceType {
	result := UNKNOWN

	if strings.TrimSpace(deviceType) != "" {
		result = DeviceType(strings.TrimSpace(strings.ToUpper(deviceType)))
	}
	return result
}
